function show_checkerboard_grid(imagePoints,worldPoints,color)
% SHOW_CHECKERBOARD_GRID(imagePoints,worldPoints,color)  plots the
%    connected rows and columns of the checkerboard
%
%    imagePoints are corner locations (e.g. from MATLAB calibrator)
%    worldPoints are corresponding world coordinates.
%    color is an optional color specification
%
%    The points would typically be size (64, 2)
%
%      Examples:
%    show_checkerboard_grid(imagePoints, worldPoints)
%            shows the grid alone
%
%     imshow(rgb);
%     hold on
%     show_checkerboard_grid(imagePoints, worldPoints, 'y');
%            superimposes grid (in yellow) on image
%

%     copyright 2017   John S. Loomis

if nargin<3
    color='k';
end
label = false;
nsq = 8;
for count=1:nsq
    ndx = find(worldPoints(:,1)==(count-1)*3);
    plot(imagePoints(ndx,1),imagePoints(ndx,2),color,'LineWidth',2);
    if label
        for m = 1:8
            text(imagePoints(ndx(m),1),imagePoints(ndx(m),2),num2str(ndx(m)));
        end
    end
    hold on
end
for count=1:nsq
    ndx = find(worldPoints(:,2)==(count-1)*3);
    plot(imagePoints(ndx,1),imagePoints(ndx,2),color,'LineWidth',2);
    hold on
end
ndx = find(and(worldPoints(:,1)==0,worldPoints(:,2)==0));
plot(imagePoints(ndx,1),imagePoints(ndx,2),[color 'o'],'MarkerSize',7,'LineWidth',2);
hold off
axis ij